@@ -4,7 +4,7 @@
 """A library that provides a Python interface to the Telegram Bots API"""
 
 __author__ = 'leandrotoledodesouza@gmail.com'
-__version__ = '1.0'
+__version__ = '1.1'
 
 import json
 
@@ -20,10 +20,11 @@ from video import Video
 from contact import Contact
 from location import Location
 from chataction import ChatAction
-# from inputfile import InputFile
 from userprofilephotos import UserProfilePhotos
-# from replykeyboardmarkup import ReplyKeyboardMarkup
-# from replykeyboardhide import ReplyKeyboardHide
-# from forcereply import ForceReply
+from replykeyboardmarkup import ReplyKeyboardMarkup
+from replykeyboardhide import ReplyKeyboardHide
+from forcereply import ForceReply
+from replymarkup import ReplyMarkup
 from error import TelegramError
+from emoji import Emoji
 from bot import Bot
