@@ -2,23 +2,23 @@
 
 
 class Document(object):
-    def __init__(self, **kwargs):
-        param_defaults = {
-            'file_id': None,
-            'thumb': None,
-            'file_name': None,
-            'mime_type': None,
-            'file_size': None
-        }
-
-        for (param, default) in param_defaults.iteritems():
-            setattr(self, param, kwargs.get(param, default))
+    def __init__(self,
+                 file_id,
+                 thumb,
+                 file_name=None,
+                 mime_type=None,
+                 file_size=None):
+        self.file_id = file_id
+        self.thumb = thumb
+        self.file_name = file_name
+        self.mime_type = mime_type
+        self.file_size = file_size
 
     @staticmethod
-    def newFromJsonDict(data):
+    def de_json(data):
         if 'thumb' in data:
             from telegram import PhotoSize
-            thumb = PhotoSize.newFromJsonDict(data['thumb'])
+            thumb = PhotoSize.de_json(data['thumb'])
         else:
             thumb = None
 
