@@ -2,22 +2,19 @@
 
 
 class UserProfilePhotos(object):
-    def __init__(self, **kwargs):
-        param_defaults = {
-            'total_count': None,
-            'photos': None
-        }
-
-        for (param, default) in param_defaults.iteritems():
-            setattr(self, param, kwargs.get(param, default))
+    def __init__(self,
+                 total_count,
+                 photos):
+        self.total_count = total_count
+        self.photos = photos
 
     @staticmethod
-    def newFromJsonDict(data):
+    def de_json(data):
         if 'photos' in data:
             from telegram import PhotoSize
             photos = []
             for photo in data['photos']:
-                photos.append([PhotoSize.newFromJsonDict(x) for x in photo])
+                photos.append([PhotoSize.de_json(x) for x in photo])
         else:
             photos = None
 
