@@ -2,26 +2,29 @@
 
 
 class Video(object):
-    def __init__(self, **kwargs):
-        param_defaults = {
-            'file_id': None,
-            'width': None,
-            'height': None,
-            'duration': None,
-            'thumb': None,
-            'mime_type': None,
-            'file_size': None,
-            'caption': None
-        }
-
-        for (param, default) in param_defaults.iteritems():
-            setattr(self, param, kwargs.get(param, default))
+    def __init__(self,
+                 file_id,
+                 width,
+                 height,
+                 duration,
+                 thumb,
+                 mime_type=None,
+                 file_size=None,
+                 caption=None):
+        self.file_id = file_id
+        self.width = width
+        self.height = height
+        self.duration = duration
+        self.thumb = thumb
+        self.mime_type = mime_type
+        self.file_size = file_size
+        self.caption = caption
 
     @staticmethod
-    def newFromJsonDict(data):
+    def de_json(data):
         if 'thumb' in data:
             from telegram import PhotoSize
-            thumb = PhotoSize.newFromJsonDict(data['thumb'])
+            thumb = PhotoSize.de_json(data['thumb'])
         else:
             thumb = None
 
